===================
PyAMS_apm package
===================

Introduction
------------

This package is composed of a set of utility functions, usable into any Pyramid application.

    >>> from pyramid.testing import setUp, tearDown
    >>> config = setUp()

    >>> from pyams_apm import *
    >>> from pyams_apm.tween import *

    >>> tearDown()
